@@ -15,7 +15,6 @@
 #' @import dplyr
 #' @import reshape2
 #' @import ggplot2
-#' @import agricolae
 #' @param x a data frame of 4 columns including Conditions, E (efficiency), Gene and Ct values (see example below). Biological replicates needs to be equal for all Genes. Each Ct value is the mean of technical replicates. Complete amplification efficiencies of 2 is assumed here for all wells but the calculated efficienies can be used instead.
 #' @param paired a logical indicating whether you want a paired t-test.
 #' @param var.equal a logical variable indicating whether to treat the two variances as being equal. If TRUE then the pooled variance is used to estimate the variance otherwise the Welch (or Satterthwaite) approximation to the degrees of freedom is used.
@@ -70,10 +69,7 @@
 
 
 
-qpcrTTEST <- function(x,
-                      numberOfrefGenes,
-                      paired = FALSE,
-                      var.equal = TRUE) {
+qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
 
   colnames(x)[1] <- "Condition"
   colnames(x)[2] <- "Gene"
