@@ -17,7 +17,6 @@
 #' @import dplyr
 #' @import reshape2
 #' @import ggplot2
-#' @import agricolae
 #' @param x a data frame. The data frame consists of 4 columns belonging to condition levels, E (efficiency), genes and Ct values, respectively. Each Ct in the following data frame is the mean of technical replicates. Complete amplification efficiencies of 2 is assumed here for all wells but the calculated efficienies can be used we well. We use this data set for Fold Change expression analysis of the target genes in treatment condition compared to normal condition.
 #' @param numberOfrefGenes number of reference genes. Up to two reference genes can be handled.
 #' @param order a vector determining genes order on the output graph.
@@ -65,23 +64,11 @@
 #'
 
 
-qpcrTTESTplot <- function(x,
-                          order = "none",
-                          numberOfrefGenes,
-                          paired = FALSE,
-                          var.equal = TRUE,
-                          width = 0.5,
-                          fill = "skyblue",
-                          y.axis.adjust = 0,
-                          y.axis.by = 2,
-                          letter.position.adjust = 0.3,
-                          ylab = "Average Fold Change",
-                          xlab = "none",
-                          fontsize = 12,
-                          fontsizePvalue = 7,
-                          axis.text.x.angle = 0,
-                          axis.text.x.hjust = 0.5,
-                          errorbar = "se"){
+qpcrTTESTplot <- function(x, order = "none", numberOfrefGenes, paired = FALSE,
+                          var.equal = TRUE, width = 0.5, fill = "skyblue", y.axis.adjust = 0,
+                          y.axis.by = 2, letter.position.adjust = 0.3, ylab = "Average Fold Change",
+                          xlab = "none", fontsize = 12, fontsizePvalue = 7, axis.text.x.angle = 0,
+                          axis.text.x.hjust = 0.5, errorbar = "se"){
 
   default.order <- unique(x[,2])[-length(unique(x[,2]))]
 
