@@ -10,7 +10,6 @@
 #' @import dplyr
 #' @import reshape2
 #' @import ggplot2
-#' @import agricolae
 #' @param res the FC data frame created by \code{qpcrANOVARE(x)$Result} function on a two factor data such as \code{data_2factor}.
 #' @param x.axis.factor x-axis factor.
 #' @param group.factor grouping factor.
@@ -89,30 +88,22 @@
 
 
 
-twoFACTORplot <- function(res,
-                          x.axis.factor,
-                          group.factor,
-                          width = 0.5,
-                          fill = "Blues",
-                          y.axis.adjust = 0.5,
-                          y.axis.by = 2,
-                          show.errorbars = TRUE,
-                          errorbar = "se",
-                          show.letters = TRUE,
-                          letter.position.adjust = 0.1,
-                          ylab = "Relative Expression",
-                          xlab = "none",
-                          legend.position = c(0.09, 0.8),
-                          fontsize = 12,
-                          fontsizePvalue = 5,
-                          axis.text.x.angle = 0,
-                          axis.text.x.hjust = 0.5){
+twoFACTORplot <- function(res, x.axis.factor, group.factor, width = 0.5, fill = "Blues", 
+                          y.axis.adjust = 0.5, y.axis.by = 2, show.errorbars = TRUE,
+                          errorbar = "se", show.letters = TRUE, letter.position.adjust = 0.1,
+                          ylab = "Relative Expression", xlab = "none", legend.position = c(0.09, 0.8),
+                          fontsize = 12, fontsizePvalue = 5, axis.text.x.angle = 0, axis.text.x.hjust = 0.5){
   b <- res
   se <- b$se
   LCL <- b$LCL
   UCL <- b$UCL
   
   
+  if (any(grepl("letters", names(b)))) {
+    b$letters <- gsub(" ", "", b$letters)
+  }
+  
+  
   if (any(grepl("RE", names(b)))) {
     RE <- b$RE
     if(errorbar == "se") { 
